xmlrpclib.Transport

Module xmlrpclib :: Class Transport |
[show private | hide private]
[frames | no frames]

## Class Transport

Known Subclasses:
  `XMLRPCTransport`

Handles an HTTP transaction to an XML-RPC server.

Method Summary
| `get_host_info(self, host)`
| `getparser(self)`
| `make_connection(self, host)`
| `parse_response(self, file)`
| `request(self, host, handler, request_body, verbose)`
| `send_content(self, connection, request_body)`
| `send_host(self, connection, host)`
| `send_request(self, connection, handler, request_body)`
| `send_user_agent(self, connection)`

Class Variable Summary
`str` | `user_agent` = `'xmlrpclib.py/1.0.1 (by www.pythonware.com)...`

Class Variable Details

    ### user_agent Type: `str` Value:
        'xmlrpclib.py/1.0.1 (by www.pythonware.com)'

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net